###
# Copyright © 2015, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright © 2016, Mopi
# Copyright © 2017, Phil Morrell
# Copyright © 2017, Jacek Szafarkiewicz
# Copyright © 2018, VA
# Copyright © 2018, Janeene "dawnmist" Beeforth
# Copyright © 2018, BetaRays
# Copyright © 2018, Andrey
# Copyright © 2019, Emmanuel Gil Peyrot <linkmauve@linkmauve.fr>
# Copyright © 2020, macaron
# Copyright © 2020, Hoël Bézier
# Copyright © 2020, quinao
# Copyright © 2022, JashinYoda
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# common functions for ./play.it scripts
# send your bug reports to bugs@dotslashplay.it
###

PLAYIT_LIBRARY_VERSION=2.35.1
PLAYIT_LIBRARY_REVISION=20260414.1

