# Print Debian packages providing given packages list, set using legacy dependencies system.
# USAGE: dependencies_legacy_list_debian $dependencies_legacy
dependencies_legacy_list_debian() {
	local dependencies_legacy
	dependencies_legacy="$1"

	printf '%s\n' $dependencies_legacy
}

