# List the identifiers of the archives supported by the current game script.
# The archive identifiers are separated by line breaks.
# USAGE: archives_list_identifiers
archives_list_identifiers() {
	set |
		sed --silent 's/^\(ARCHIVE_BASE\(_[0-9A-Z]\+\)*_[0-9]\+\)\(_NAME\)\?=.*/\1/p' |
		sort --reverse --version-sort
}

