# Arch Linux - Print installation instructions.
# USAGE: print_instructions_arch $package[…]
print_instructions_arch() {
	local path_output_directory
	path_output_directory=$(path_output_directory)

	printf 'pacman -U'

	local package package_name
	for package in "$@"; do
		package_name=$(package_name "$package")
		# TODO: The following path could be computed from a dedicated function.
		printf ' "%s"' "${path_output_directory}/${package_name}"
	done

	printf '\n'
}

