# Print Gentoo packages providing sibling packages list.
# USAGE: dependencies_siblings_list_gentoo $dependencies_siblings
dependencies_siblings_list_gentoo() {
	local dependencies_siblings
	dependencies_siblings="$1"

	local dependency_sibling
	while read -r dependency_sibling; do
		dependencies_sibling_single_gentoo "$dependency_sibling"
	done <<- EOL
	$(printf '%s' "$dependencies_siblings")
	EOL
}

# Print Gentoo package providing given single sibling package.
# USAGE: dependencies_sibling_single_gentoo $dependency_sibling
dependencies_sibling_single_gentoo() {
	local dependency_sibling
	dependency_sibling="$1"

	local package_id
	package_id=$(package_id "$dependency_sibling")
	printf 'games-playit/%s\n' "$package_id"
}

