# Print Arch Linux packages providing given Mono libraries list.
# USAGE: dependencies_mono_list_archlinux $dependencies_mono
dependencies_mono_list_archlinux() {
	# Arch Linux provides all Mono libraries in a single "mono" package.
	printf '%s\n' 'mono'
}

