# Error - $script_version does not follow the expected format
# USAGE: error_invalid_version_string $version_string
error_invalid_version_string() {
	local version_string
	version_string="$1"

	local messages_language message
	messages_language=$(messages_language)
	case "$messages_language" in
		('fr')
			message='La valeur suivante de $script_version ne respecte pas le format attendu : %s\n'
			message="$message"'Le format correct est "YYYYMMDD.N", avec "YYYYMMDD" la date de dernière édition du script, et "N" un nombre incrémenté si le script est édité plusieurs fois dans la même journée.\n'
		;;
		('en'|*)
			message='The following $script_version value does not follow the expected format: %s\n'
			message="$message"'The correct format is "YYYYMMDD.N", with "YYYYMMDD" the date of the last edition of the script, and "N" a number incremented if the script is edited multiple times at the same date.\n'
		;;
	esac
	print_message 'error' "$message" \
		"$version_string"
}

