# Compatibility wrappers for ≤ 2.34 compatibility levels

persistent_storage_update_files_from_prefix() {
	if compatibility_level_is_at_least 2.35; then
		warning_deprecated_function 'persistent_storage_update_files_from_prefix' 'persistent_storage_update_files'
	fi
	persistent_storage_update_files
}

