# Print the DOSBox pre-run actions for the given application.
# These actions are run inside DOSBox.
# USAGE: dosbox_prerun $application
dosbox_prerun() {
	local application
	application="$1"

	context_value "${application}_DOSBOX_PRERUN"
}

# Print the DOSBox post-run actions for the given application.
# These actions are run inside DOSBox.
# USAGE: dosbox_postrun $application
dosbox_postrun() {
	local application
	application="$1"

	context_value "${application}_DOSBOX_POSTRUN"
}

