# Unreal Engine 4 - Print the default wrestool options string
# USAGE: unrealengine4_icon_wrestool_options_default
# RETURN: the options string to pass to wrestool
unrealengine4_icon_wrestool_options_default() {
	printf '%s' '--type=14 --name=101'
}

