# Set default list of paths to include for GameMaker games.
# USAGE: content_files_gamemaker $content_id
content_files_gamemaker() {
	local content_id
	content_id="$1"

	local content_files
	case "$content_id" in
		('GAME_BIN')
			content_files='
			runner'
		;;
		('GAME_DATA')
			content_files='
			assets'
		;;
	esac

	printf '%s' "${content_files:-}"
}

