# Print Gentoo packages providing given Mono libraries list.
# USAGE: dependencies_mono_list_gentoo $dependencies_mono
dependencies_mono_list_gentoo() {
	# Gentoo provides all Mono libraries in a single "dev-lang/mono" package.
	printf '%s\n' 'dev-lang/mono'
}

