complete -c play.it -l checksum -x -a "md5 none" -d "Archive integrity verification method"
complete -c play.it -l collection-path -r -d "Limit the search for game scripts to given path"
complete -c play.it -l compression -x -a "none speed size auto" -d "Generated packages compression method"
complete -c play.it -l config-file -r -d "Configuration file path"
complete -c play.it -l no-free-space-check -f -d "Do not check for free space"
complete -c play.it -l no-icons -f -d "Do not include game icons"
complete -c play.it -l no-mtree -f -d "Do not create .MTREE in Arch Linux packages"
complete -c play.it -l output-dir -r -d "Output directory for generated packages"
complete -c play.it -l overwrite -f -d "Replace existing packages"
complete -c play.it -l package -x -a "arch deb gentoo" -d "Generated package type"
complete -c play.it -l prefix -x -d "Game installation path"
complete -c play.it -l tmpdir -r -d "Temporary files directory"
complete -c play.it -l list-packages -f -d "Print the list of packages to build"
complete -c play.it -l list-requirements -f -d "Print the list of commands required to build packages"
complete -c play.it -l show-game-script -f -d "Display game script instead of running it"
complete -c play.it -l list-available-scripts -f -d "Print the list of available game scripts"
complete -c play.it -l list-supported-games -f -d "Print the list of supported games"
