# Print Arch Linux packages providing given packages list, set using legacy dependencies system.
# USAGE: dependencies_legacy_list_archlinux $dependencies_legacy
dependencies_legacy_list_archlinux() {
	local dependencies_legacy
	dependencies_legacy="$1"

	## FIXME: A "lib32-" prefix might be required for 32-bit packages.
	printf '%s\n' $dependencies_legacy
}

