# Visionaire - Prevent the use of Linux-specific SDL backends.
# This should only be applied to Windows games running through WINE.
# USAGE: visionaire_tweak_sdl_wine
## TODO: This might be worth applying to all WINE games, not only Visionaire ones.
visionaire_tweak_sdl_wine() {
	cat <<- 'EOF'
	# Prevent the use of Linux-specific SDL backends.
	unset SDL_AUDIODRIVER SDL_VIDEODRIVER

	EOF
}

