# Warning: A .deb package is going over the 9GB size limit
# USAGE: warning_debian_size_limit $package
warning_debian_size_limit() {
	local package
	package="$1"

	local messages_language message
	messages_language=$(messages_language)
	case "$messages_language" in
		('fr')
			message='Le paquet suivant est trop gros pour le format .deb moderne : %s\n'
		;;
		('en'|*)
			message='The following package is too big for .deb modern format: %s\n'
		;;
	esac
	print_message 'warning' "$message" \
		"$package"
}
