# Print Gentoo packages providing given packages list, set using legacy dependencies system.
# USAGE: dependencies_legacy_list_gentoo $dependencies_legacy
dependencies_legacy_list_gentoo() {
	local dependencies_legacy
	dependencies_legacy="$1"

	# This now only supports sibling dependencies for non-updated scripts
	printf 'games-playit/%s\n' $dependencies_legacy
}

