# Gentoo - Print installation instructions.
# USAGE: print_instructions_gentoo $package[…]
print_instructions_gentoo() {
	local path_output_directory
	path_output_directory=$(path_output_directory)

	local emerge_pkgdir emerge_features
	emerge_pkgdir=$(dirname "$path_output_directory")
	emerge_features='-pkgdir-index-trusted'

	printf 'PKGDIR="%s" FEATURES="%s" emerge' "$emerge_pkgdir" "$emerge_features"

	local package package_name
	for package in "$@"; do
		package_name=$(package_name "$package")
		# TODO: The following path could be computed from a dedicated function.
		printf ' "%s"' "${path_output_directory}/${package_name}"
	done
	printf '\n'
}

