# Error - No source of game scripts could be found.
# USAGE: error_no_collection
error_no_collection() {
	local messages_language message
	messages_language=$(messages_language)
	case "$messages_language" in
		('fr')
			message='Aucune collection ajoutant la prise en charge de jeux n’a été trouvée.\n'
			message="$message"'Des instructions pour en ajouter peuvent se trouver sur la page suivante :\n'
			message="$message"'%s\n'
		;;
		('en'|*)
			message='No collection adding support for games has been found.\n'
			message="$message"'Installation instructions for games collections can be found on the following page:\n'
			message="$message"'%s\n'
		;;
	esac
	print_message 'error' "$message" \
		'https://git.dotslashplay.it/scripts/about/#game-scripts'
}

