# Compute the icon path from the APP_xxx_EXE value
# USAGE: icon_wine_path $icon_identifier
icon_wine_path() {
	local icon_identifier
	icon_identifier="$1"

	local application application_exe
	application=$(icon_application "$icon_identifier")
	application_exe=$(application_exe "$application")

	printf '%s' "$application_exe"
}
