# Print the list of winetricks verbs installed by default for Unreal Engine 3 games.
# USAGE: wine_winetricks_verbs_unrealengine3
wine_winetricks_verbs_unrealengine3() {
	# Cursor is prevented from leaving the game window, avoiding problems with mouse look.
	# (WINE 10.0)
	printf '%s' 'grabfullscreen=y'
}

# Set the default virtual desktop setting for Unreal Engine 3 games.
# USAGE: wine_virtual_desktop_unrealengine3
wine_virtual_desktop_unrealengine3() {
	# Without a virtual desktop, keyboard inputs are ignored.
	# (WINE 10.0)
	printf '%s' 'auto'
}

